class simec::postgresql (
$db_username   = $::simec::params::db_username,
$db_password   = $::simec::params::db_password,
$db_name       = $::simec::params::db_name,
$db_host       = $::simec::params::db_host,
$db_port       = $::simec::params::db_port,
) inherits simec::params {


	case $::osfamily {

            'RedHat': {

		# Instar o repositório
		yumrepo { 'base' :
                        exclude => "\"postgresql*\"",
                        notify      => Exec['postgres_repo'],
                }
        	exec { 'postgres_repo':
                        command     => "yum localinstall https://download.postgresql.org/pub/repos/yum/9.3/redhat/rhel-7-x86_64/pgdg-centos93-9.3-2.noarch.rpm -y",
                        path        => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
			require     => Yumrepo['base'],
                        refreshonly => true,
        	}
		
		package { [ 'epel-release', 'postgresql93-server', 'postgresql93', 'postgresql93-libs', 'postgresql93-contrib' ] :
                	ensure => installed,
                	notify => Exec['run_initdb'],
                	require => Exec['postgres_repo']
        	}->
        	package { [ 'gdal', 'gdal-devel', 'gdal-java', 'gdal-perl', 'gdal-python' ] :
                	ensure => installed,
                	require => Exec['run_initdb']
        	}->
        	package { [ 'postgis2_93', 'postgis2_93-devel', 'postgis2_93-docs', 'postgis2_93-utils' ] :
                	ensure => installed
        	}->
        	pg_hba { "host to $db_username on $db_name from $::ipaddress/32":
                	ensure => present,
                	method => 'md5',
                	target => '/var/lib/pgsql/9.3/data/pg_hba.conf',
        	}->
        	file { '/var/lib/pgsql/9.3/data/postgresql.conf':
                  	force   => true,
                  	ensure  => 'file',
                  	group   => 'postgres',
                  	mode    => '600',
                  	owner   => 'postgres',
                  	content => template('simec/postgresql.conf.centos.erb'),
                  	notify  => [
                                Service['postgresql'],
                                Exec['setup_db']
                             ]
        	}

		exec { 'run_initdb':
                	command     => "/usr/pgsql-9.3/bin/postgresql93-setup initdb",
                	path        => '/usr/bin:/usr/sbin:/bin:/usr/local/bin:/usr/pgsql-9.3/bin',
                	refreshonly => true,
        	}

		service { 'postgresql':
                	name    => 'postgresql-9.3',
                	ensure  => running,
                	enable  => true,
                	require => File['/var/lib/pgsql/9.3/data/postgresql.conf'],
        	}




		augeas { "turn off sudo requiretty":
                        changes => [
                                'set /files/etc/sudoers/Defaults[*]/requiretty/negate ""',
                        ],
        	}

		exec { 'restore_db':
                	environment => "PGPASSWORD=$db_password",
                	command     => "gunzip -c /opt/dump_simec.tar.gz | pg_restore -h $db_host -U $db_username -v -p $db_port -d $db_name 2> /tmp/out_restore_$db_name",
                	path        => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
                	require     => [
                                Service['postgresql'],
                                File['/opt/dump_simec.tar.gz'],
                                Augeas['turn off sudo requiretty'],
                               ],
                	returns => [0, 1],
                	refreshonly => true,
        	}	

            }

            'Debian': {
		
		# instalar repositorio
		file { '/opt/apt.postgresql.org.sh':
			 ensure  => file,
                	 mode    => '0754',
                	 owner   => 'root',
                	 group   => 'root',
                	 source  => 'puppet:///modules/simec/apt.postgresql.org.sh',
                         notify  => Exec['postgres_repo_apt']
                }
		exec { 'postgres_repo_apt':
                        command     => "sh /opt/apt.postgresql.org.sh",
                        path        => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
                        require     => File['/opt/apt.postgresql.org.sh'],
                        refreshonly => true,
                }

		package { [ 'postgresql-9.3-postgis-2.1', 'postgresql-9.3-postgis-2.1-scripts',  'postgresql-client-9.3', 'postgresql-contrib-9.3' ] :
                        ensure => installed,
                        require => Exec['postgres_repo_apt']
                }->
		pg_hba { "host to $db_username on $db_name from $::ipaddress/32":
                        ensure => present,
                        method => 'md5',
                        target => '/etc/postgresql/9.3/main/pg_hba.conf',
                }->
		file { '/etc/postgresql/9.3/main/postgresql.conf':
                        force   => true,
                        ensure  => 'file',
                        group   => 'postgres',
                        mode    => '600',
                        owner   => 'postgres',
                        content => template('simec/postgresql.conf.debian.erb'),
                        notify  => [
                                Service['postgresql'],
                                Exec['setup_db']
                             ]
                }

		service { 'postgresql':
                	name    => 'postgresql',
                	ensure  => running,
                	enable  => true,
                	require => [
                        	File['/etc/postgresql/9.3/main/postgresql.conf'],
                	],
        	}

		exec { 'restore_db':
                	environment => "PGPASSWORD=$db_password",
                	command     => "gunzip -c /opt/dump_simec.tar.gz | pg_restore -h $db_host -U $db_username -v -p $db_port -d $db_name 2> /tmp/out_restore_$db_name",
                	path        => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
                	require     => [
                                Service['postgresql'],
                                File['/opt/dump_simec.tar.gz']
                               ],
                	returns => [0, 1],
                	refreshonly => true,
        	}
            }


            default: {
              fail("${module_name} module is not supported on osfamily ${::osfamily}.")
            }

          }

	file { '/opt/dump_simec.tar.gz':
                ensure  => file,
                mode    => '0644',
                owner   => 'root',
                group   => 'root',
                source  => 'puppet:///modules/simec/dump_simec.tar.gz',
        }

	exec { 'setup_db':	
                command     => "sudo -u postgres psql -c \"create user $db_username with password \'$db_password\' superuser;\" && sudo -u postgres psql -c \"create database $db_name with owner = $db_username encoding \'UTF8\'\"",
                path        => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
		require     => Service['postgresql'],
		notify      => Exec['restore_db'],
                refreshonly => true
        }
}
